## Билдеры

- [`Builder`](builders/builder.md){:target="_blank"} - Объект клавиатуры.
- [`ImageGalleryBuilder`](builders/image-gallery-builder.md){:target="_blank"} - Билдер альбомов.
- [`ItemsListBuilder`](builders/items-list-builder.md){:target="_blank"} - Билдер элементов списка.
- [`TextButtonBuilder`](builders/text-button-builder.md){:target="_blank"} - Билдер текстовых кнопок.

### [Примеры](https://github.com/K1rL3s/aliceio/blob/master/examples/builders.py){:target="_blank"} использования билдеров
